'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactNative = require('react-native');

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

var styles = reactNative.StyleSheet.create({
  button: {
    borderColor: "#c2c2c2",
    borderWidth: 1,
    alignItems: "center",
    flex: 1,
    backgroundColor: "white",
    flexDirection: "row",
    padding: 20
  },
  buttonText: {
    fontSize: 14,
    fontWeight: "bold",
    padding: 4,
    flex: 1,
    textAlign: "left"
  },
  modal: {
    position: "absolute",
    maxHeight: 200
  },
  separator: {
    borderColor: "#c2c2c2",
    borderTopWidth: 1
  },
  list: {
    flex: 1,
    borderColor: "#c2c2c2",
    borderWidth: 1,
    borderTopWidth: 0,
    backgroundColor: "white"
  },
  item: {
    fontSize: 14,
    fontWeight: "bold",
    flex: 1,
    textAlign: "left",
    paddingTop: 10,
    paddingLeft: 20,
    paddingBottom: 10,
    paddingRight: 20,
    color: "#999999"
  },
  selectedItem: {
    color: "black"
  },
  overlay: _objectSpread2({}, reactNative.StyleSheet.absoluteFillObject, {
    backgroundColor: "transparent"
  }),
  chevron: {
    borderTopWidth: 2,
    borderRightWidth: 2,
    width: 8,
    height: 8,
    transform: [{
      rotate: "135deg"
    }]
  }
});

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

const DefaultLabelExtractor = item => "value" in item && item.value.toString() || "";

const DefaultSeparator = () => React__default.createElement(reactNative.View, {
  style: styles.separator
});

const InlinePicker = (_ref) => {
  let {
    renderButtonContent,
    buttonStyle,
    selectedIndex,
    onChange,
    data,
    placeholderText,
    renderItem,
    labelExtractor = DefaultLabelExtractor,
    ItemSeparatorComponent = DefaultSeparator,
    listWidth = "auto"
  } = _ref,
      listProps = _objectWithoutProperties(_ref, ["renderButtonContent", "buttonStyle", "selectedIndex", "onChange", "data", "placeholderText", "renderItem", "labelExtractor", "ItemSeparatorComponent", "listWidth"]);

  const buttonRef = React.useRef(null);
  const listRef = React.useRef(null);
  const [position, setPosition] = React.useState({
    top: 0,
    left: 0,
    width: 0
  });
  const [showModal, setShowModal] = React.useState(false);
  const [status, setStatus] = React.useState("");
  const defaultItemRenderer = React.useCallback(info => React__default.createElement(reactNative.Text, {
    style: [styles.item, selectedIndex === info.index && styles.selectedItem]
  }, labelExtractor(info.item)), [selectedIndex, labelExtractor]);
  const renderFunction = renderItem || defaultItemRenderer;
  const measure = React.useCallback(() => {
    if (buttonRef.current) {
      //   buttonRef.current.measureInWindow((x, y, width, height) => {
      //     setStatus(JSON.stringify({ x, y, width, height }));
      //   });
      buttonRef.current.measureInWindow((x, y, width, height) => {
        // setStatus(JSON.stringify({ _x, _y, width, height, pageX, pageY }));
        setPosition({
          left: x,
          top: y + height,
          width: listWidth === "auto" ? width : listWidth
        });
      });
    }
  }, [buttonRef.current]);
  const onLayout = React.useCallback(() => {
    measure();
  }, [measure]);
  const hidePopup = React.useCallback(() => {
    setShowModal(false);
  }, []);
  const showPopup = React.useCallback(() => {
    setShowModal(true);
    measure();
  }, [measure]);
  const itemRenderer = React.useCallback(info => React__default.createElement(reactNative.TouchableOpacity, {
    onPress: () => {
      setShowModal(false);
      onChange && onChange(info.item, info.index);
    }
  }, renderFunction(info)), [renderItem, onChange]);
  const defaultButtonContent = React.useCallback((selectedItem, placeholderText) => React__default.createElement(React__default.Fragment, null, React__default.createElement(reactNative.Text, {
    style: styles.buttonText
  }, selectedItem ? labelExtractor(selectedItem) : placeholderText), React__default.createElement(reactNative.View, {
    style: styles.chevron
  })), [labelExtractor]);
  const buttonRender = renderButtonContent || defaultButtonContent;
  const selectedItem = selectedIndex && selectedIndex > 0 || selectedIndex === 0 ? data[selectedIndex] : undefined;
  return React__default.createElement(React__default.Fragment, null, React__default.createElement(reactNative.TouchableOpacity, {
    style: [styles.button, buttonStyle],
    onLayout: onLayout,
    onPress: showPopup,
    ref: buttonRef
  }, buttonRender(selectedItem, placeholderText)), React__default.createElement(reactNative.Text, null, status), React__default.createElement(reactNative.Modal, {
    visible: showModal,
    onRequestClose: hidePopup,
    transparent: true
  }, React__default.createElement(reactNative.View, {
    style: styles.overlay,
    onStartShouldSetResponder: () => true,
    onResponderRelease: hidePopup
  }, React__default.createElement(reactNative.View, {
    style: [styles.modal, position]
  }, React__default.createElement(reactNative.FlatList, _extends({}, listProps, {
    ItemSeparatorComponent: ItemSeparatorComponent,
    style: styles.list,
    renderItem: itemRenderer,
    data: data,
    ref: listRef,
    initialScrollIndex: selectedIndex
  }))))));
};

exports.InlinePicker = InlinePicker;
//# sourceMappingURL=index.js.map
