import React, { useRef, useState, useCallback } from 'react';
import { StyleSheet, Text, TouchableOpacity, View, Modal, FlatList } from 'react-native';

var styles = StyleSheet.create({
  button: {
    borderColor: "#c2c2c2",
    borderWidth: 1,
    alignItems: "center",
    flex: 1,
    backgroundColor: "white",
    flexDirection: "row",
    padding: 20
  },
  buttonText: {
    fontSize: 14,
    fontWeight: "bold",
    padding: 4,
    flex: 1,
    textAlign: "left"
  },
  modal: {
    position: "absolute",
    maxHeight: 200
  },
  separator: {
    borderColor: "#c2c2c2",
    borderTopWidth: 1
  },
  list: {
    flex: 1,
    borderColor: "#c2c2c2",
    borderWidth: 1,
    borderTopWidth: 0,
    backgroundColor: "white"
  },
  item: {
    fontSize: 14,
    fontWeight: "bold",
    flex: 1,
    textAlign: "left",
    paddingTop: 10,
    paddingLeft: 20,
    paddingBottom: 10,
    paddingRight: 20,
    color: "#999999"
  },
  selectedItem: {
    color: "black"
  },
  overlay: { ...StyleSheet.absoluteFillObject,
    backgroundColor: "transparent"
  },
  chevron: {
    borderTopWidth: 2,
    borderRightWidth: 2,
    width: 8,
    height: 8,
    transform: [{
      rotate: "135deg"
    }]
  }
});

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const DefaultLabelExtractor = item => "value" in item && item.value.toString() || "";

const DefaultSeparator = () => React.createElement(View, {
  style: styles.separator
});

const InlinePicker = ({
  renderButtonContent,
  buttonStyle,
  selectedIndex,
  onChange,
  data,
  placeholderText,
  renderItem,
  labelExtractor = DefaultLabelExtractor,
  ItemSeparatorComponent = DefaultSeparator,
  listWidth = "auto",
  ...listProps
}) => {
  const buttonRef = useRef(null);
  const listRef = useRef(null);
  const [position, setPosition] = useState({
    top: 0,
    left: 0,
    width: 0
  });
  const [showModal, setShowModal] = useState(false);
  const [status, setStatus] = useState("");
  const defaultItemRenderer = useCallback(info => React.createElement(Text, {
    style: [styles.item, selectedIndex === info.index && styles.selectedItem]
  }, labelExtractor(info.item)), [selectedIndex, labelExtractor]);
  const renderFunction = renderItem || defaultItemRenderer;
  const measure = useCallback(() => {
    if (buttonRef.current) {
      //   buttonRef.current.measureInWindow((x, y, width, height) => {
      //     setStatus(JSON.stringify({ x, y, width, height }));
      //   });
      buttonRef.current.measureInWindow((x, y, width, height) => {
        // setStatus(JSON.stringify({ _x, _y, width, height, pageX, pageY }));
        setPosition({
          left: x,
          top: y + height,
          width: listWidth === "auto" ? width : listWidth
        });
      });
    }
  }, [buttonRef.current]);
  const onLayout = useCallback(() => {
    measure();
  }, [measure]);
  const hidePopup = useCallback(() => {
    setShowModal(false);
  }, []);
  const showPopup = useCallback(() => {
    setShowModal(true);
    measure();
  }, [measure]);
  const itemRenderer = useCallback(info => React.createElement(TouchableOpacity, {
    onPress: () => {
      setShowModal(false);
      onChange && onChange(info.item, info.index);
    }
  }, renderFunction(info)), [renderItem, onChange]);
  const defaultButtonContent = useCallback((selectedItem, placeholderText) => React.createElement(React.Fragment, null, React.createElement(Text, {
    style: styles.buttonText
  }, selectedItem ? labelExtractor(selectedItem) : placeholderText), React.createElement(View, {
    style: styles.chevron
  })), [labelExtractor]);
  const buttonRender = renderButtonContent || defaultButtonContent;
  const selectedItem = selectedIndex && selectedIndex > 0 || selectedIndex === 0 ? data[selectedIndex] : undefined;
  return React.createElement(React.Fragment, null, React.createElement(TouchableOpacity, {
    style: [styles.button, buttonStyle],
    onLayout: onLayout,
    onPress: showPopup,
    ref: buttonRef
  }, buttonRender(selectedItem, placeholderText)), React.createElement(Text, null, status), React.createElement(Modal, {
    visible: showModal,
    onRequestClose: hidePopup,
    transparent: true
  }, React.createElement(View, {
    style: styles.overlay,
    onStartShouldSetResponder: () => true,
    onResponderRelease: hidePopup
  }, React.createElement(View, {
    style: [styles.modal, position]
  }, React.createElement(FlatList, _extends({}, listProps, {
    ItemSeparatorComponent: ItemSeparatorComponent,
    style: styles.list,
    renderItem: itemRenderer,
    data: data,
    ref: listRef,
    initialScrollIndex: selectedIndex
  }))))));
};

export { InlinePicker };
//# sourceMappingURL=index.js.map
